package Acme::CPANModulesBundle::Import::RSAVAGE;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: CPANLists imported from Ron Savage's blog posts

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModulesBundle::Import::RSAVAGE - CPANLists imported from Ron Savage's blog posts

=head1 VERSION

This document describes version 0.001 of Acme::CPANModulesBundle::Import::RSAVAGE (from Perl distribution Acme-CPANModulesBundle-Import-RSAVAGE), released on 2018-09-22.

=head1 DESCRIPTION

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
