# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:02:46 2018 from module list in Acme::CPANLists::Import::RSAVAGE::ArrayAndSetOperations version 0.02.

package Acme::CPANModules::Import::RSAVAGE::ArrayAndSetOperations;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://savage.net.au/Perl-modules/html/setops.report.html] (retrieved on 2016-02-21). For the full article, visit the URL.",
  entries     => [
                   { module => "Array::AsObject" },
                   { module => "Array::Compare" },
                   { module => "Array::Uniq" },
                   { module => "Array::Utils" },
                   { module => "Benchmark::Featureset::SetOps" },
                   { module => "Bit::Vector" },
                   { module => "EO::Array" },
                   { module => "Object::Array" },
                   { module => "Set::Array" },
                   { module => "Set::Bag" },
                   { module => "Set::DynamicGroups" },
                   { module => "Set::Groups" },
                   { module => "Set::Hash" },
                   { module => "Set::Light" },
                   { module => "Set::NestedGroups" },
                   { module => "Set::Object" },
                   { module => "Set::Relation" },
                   { module => "Set::Scalar" },
                   { module => "Set::SortedArray" },
                   { module => "Set::Tiny" },
                   { module => "Set::Toolkit" },
                 ],
  summary     => "CPAN modules which offer array and set operations (2012)",
};

1;
# ABSTRACT: CPAN modules which offer array and set operations (2012)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::RSAVAGE::ArrayAndSetOperations - CPAN modules which offer array and set operations (2012)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::RSAVAGE::ArrayAndSetOperations (from Perl distribution Acme-CPANModulesBundle-Import-RSAVAGE), released on 2018-09-22.

=head1 DESCRIPTION

CPAN modules which offer array and set operations (2012).

This list is generated by extracting module names mentioned in the article [http://savage.net.au/Perl-modules/html/setops.report.html] (retrieved on 2016-02-21). For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<Array::AsObject>

=item * L<Array::Compare>

=item * L<Array::Uniq>

=item * L<Array::Utils>

=item * L<Benchmark::Featureset::SetOps>

=item * L<Bit::Vector>

=item * L<EO::Array>

=item * L<Object::Array>

=item * L<Set::Array>

=item * L<Set::Bag>

=item * L<Set::DynamicGroups>

=item * L<Set::Groups>

=item * L<Set::Hash>

=item * L<Set::Light>

=item * L<Set::NestedGroups>

=item * L<Set::Object>

=item * L<Set::Relation>

=item * L<Set::Scalar>

=item * L<Set::SortedArray>

=item * L<Set::Tiny>

=item * L<Set::Toolkit>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
