# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:02:47 2018 from module list in Acme::CPANLists::Import::RSAVAGE::StopWordLists version 0.02.

package Acme::CPANModules::Import::RSAVAGE::StopWordLists;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://savage.net.au/Perl-modules/html/stopwordlists.report.html] (retrieved on 2016-02-21). For the full article, visit the URL.",
  entries     => [
                   { module => "AI::Categorizer" },
                   { module => "Benchmark::Featureset::StopWordLists" },
                   { module => "Blog::Spam" },
                   { module => "DBIx::FullTextSearch" },
                   { module => "DBIx::TextIndex" },
                   { module => "Elastic::Model" },
                   { module => "HTML::Index" },
                   { module => "Image::WordCloud" },
                   { module => "KinoSearch" },
                   { module => "KinoSearch1" },
                   { module => "Lingua::EN::Segmenter" },
                   { module => "Lingua::EN::StopWordList" },
                   { module => "Lingua::StopWords" },
                   { module => "Lucy" },
                   { module => "Perl::Critic" },
                   { module => "Pod::Spell" },
                   { module => "Pod::Weaver" },
                   { module => "Search::Glimpse" },
                   { module => "Search::Indexer::Incremental::MD5" },
                   { module => "Search::Tokenizer" },
                   { module => "Search::Tools" },
                   { module => "Test::Spelling" },
                   { module => "Text::DeDuper" },
                   { module => "Text::Language::Guess" },
                   { module => "Text::Similarity" },
                   { module => "UMLS::SenseRelate" },
                   { module => "WAIT" },
                   { module => "WordNet::Similarity" },
                   { module => "combine" },
                 ],
  summary     => "CPAN modules which offer stopword lists (2015)",
};

1;
# ABSTRACT: CPAN modules which offer stopword lists (2015)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::RSAVAGE::StopWordLists - CPAN modules which offer stopword lists (2015)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::RSAVAGE::StopWordLists (from Perl distribution Acme-CPANModulesBundle-Import-RSAVAGE), released on 2018-09-22.

=head1 DESCRIPTION

CPAN modules which offer stopword lists (2015).

This list is generated by extracting module names mentioned in the article [http://savage.net.au/Perl-modules/html/stopwordlists.report.html] (retrieved on 2016-02-21). For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<AI::Categorizer>

=item * L<Benchmark::Featureset::StopWordLists>

=item * L<Blog::Spam>

=item * L<DBIx::FullTextSearch>

=item * L<DBIx::TextIndex>

=item * L<Elastic::Model>

=item * L<HTML::Index>

=item * L<Image::WordCloud>

=item * L<KinoSearch>

=item * L<KinoSearch1>

=item * L<Lingua::EN::Segmenter>

=item * L<Lingua::EN::StopWordList>

=item * L<Lingua::StopWords>

=item * L<Lucy>

=item * L<Perl::Critic>

=item * L<Pod::Spell>

=item * L<Pod::Weaver>

=item * L<Search::Glimpse>

=item * L<Search::Indexer::Incremental::MD5>

=item * L<Search::Tokenizer>

=item * L<Search::Tools>

=item * L<Test::Spelling>

=item * L<Text::DeDuper>

=item * L<Text::Language::Guess>

=item * L<Text::Similarity>

=item * L<UMLS::SenseRelate>

=item * L<WAIT>

=item * L<WordNet::Similarity>

=item * L<combine>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
