# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:02:46 2018 from module list in Acme::CPANLists::Import::RSAVAGE::ClassesRolesWithMooAndMoos version 0.02.

package Acme::CPANModules::Import::RSAVAGE::ClassesRolesWithMooAndMoos;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://savage.net.au/Module-reviews/html/gci.2012.url.mapper.modules.html] (retrieved on 2016-02-21). For the full article, visit the URL.",
  entries     => [
                   { module => "CGI::Application::Plugin::ActionDispatch" },
                   { module => "CGI::Application::Plugin::REST" },
                   { module => "CGI::Application::Plugin::Routes" },
                   { module => "CGI::Application::URIMapping" },
                   { module => "CGI::Easy::URLconf" },
                   { module => "Catalyst::Dispatcher" },
                   { module => "Dancer::Plugin::Dispatcher" },
                   { module => "Dancer::Route" },
                   { module => "Forward::Routes" },
                   { module => "HTTP::Router::Route" },
                   { module => "Jifty::Dispatcher" },
                   { module => "Mojo::Base" },
                   { module => "Mojolicious::Routes" },
                   { module => "Path::Dispatcher" },
                   { module => "Path::Extended" },
                   { module => "Path::Router" },
                   { module => "Pickles::Dispatcher" },
                   { module => "Pinwheel::Mapper" },
                   { module => "Plack::App::Path::Router" },
                   { module => "Plack::App::Path::Router::PSGI" },
                   { module => "Plack::App::URLMap" },
                   { module => "Plack::Util::Accessor" },
                   { module => "PlackX::RouteBuilder" },
                   { module => "REST::Application::Routes" },
                   { module => "Router::Dumb" },
                   { module => "Router::Generic" },
                   { module => "Router::Simple" },
                   { module => "Routes::Tiny" },
                   { module => "Scaffold::Routes" },
                   { module => "Silki::Action::REST" },
                   { module => "Sleep::Routes" },
                   { module => "Web::API::Mapper" },
                   { module => "Web::Dispatcher::Simple" },
                   { module => "Web::Simple" },
                 ],
  summary     => "Classes and Roles with Moo and Moos (2012)",
};

1;
# ABSTRACT: Classes and Roles with Moo and Moos (2012)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::RSAVAGE::ClassesRolesWithMooAndMoos - Classes and Roles with Moo and Moos (2012)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::RSAVAGE::ClassesRolesWithMooAndMoos (from Perl distribution Acme-CPANModulesBundle-Import-RSAVAGE), released on 2018-09-22.

=head1 DESCRIPTION

Classes and Roles with Moo and Moos (2012).

This list is generated by extracting module names mentioned in the article [http://savage.net.au/Module-reviews/html/gci.2012.url.mapper.modules.html] (retrieved on 2016-02-21). For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<CGI::Application::Plugin::ActionDispatch>

=item * L<CGI::Application::Plugin::REST>

=item * L<CGI::Application::Plugin::Routes>

=item * L<CGI::Application::URIMapping>

=item * L<CGI::Easy::URLconf>

=item * L<Catalyst::Dispatcher>

=item * L<Dancer::Plugin::Dispatcher>

=item * L<Dancer::Route>

=item * L<Forward::Routes>

=item * L<HTTP::Router::Route>

=item * L<Jifty::Dispatcher>

=item * L<Mojo::Base>

=item * L<Mojolicious::Routes>

=item * L<Path::Dispatcher>

=item * L<Path::Extended>

=item * L<Path::Router>

=item * L<Pickles::Dispatcher>

=item * L<Pinwheel::Mapper>

=item * L<Plack::App::Path::Router>

=item * L<Plack::App::Path::Router::PSGI>

=item * L<Plack::App::URLMap>

=item * L<Plack::Util::Accessor>

=item * L<PlackX::RouteBuilder>

=item * L<REST::Application::Routes>

=item * L<Router::Dumb>

=item * L<Router::Generic>

=item * L<Router::Simple>

=item * L<Routes::Tiny>

=item * L<Scaffold::Routes>

=item * L<Silki::Action::REST>

=item * L<Sleep::Routes>

=item * L<Web::API::Mapper>

=item * L<Web::Dispatcher::Simple>

=item * L<Web::Simple>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-RSAVAGE>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-RSAVAGE>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
